@@ -1,4 +1,4 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 //
 // RcppCommon.h: Rcpp R/C++ interface class library -- common include and defines statements
 //
@@ -41,8 +41,14 @@
 # error "This compiler is not supported"
 #endif
 
+/* we define this so that INT64_MAX, etc ... are defined */
+#define __STDC_LIMIT_MACROS
+#include <limits.h>
+
+
 #include <Rcpp/config.h>
 #include <Rcpp/macros/unroll.h>
+#include <stdint.h>
 
 void logTxtFunction(const char* file, const int line, const char* expression ) ;
 
@@ -51,37 +57,37 @@ void logTxtFunction(const char* file, const int line, const char* expression ) ;
  */
 namespace Rcpp{
 
-	/**
-	 * \brief traits used to dispatch wrap
-	 */
-	namespace traits{
-	} // traits
+    /**
+     * \brief traits used to dispatch wrap
+     */
+    namespace traits{
+    } // traits
 
-	/**
-	 * \brief internal implementation details
-	 */
-	namespace internal{	
-	} // internal 
+    /**
+     * \brief internal implementation details
+     */
+    namespace internal{     
+    } // internal 
 } // Rcpp
 
 #ifdef __GNUC__
-	#define GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
-	#ifdef __GXX_EXPERIMENTAL_CXX0X__
-		#define HAS_CXX0X
-		#if GCC_VERSION >= 40300
-			#define HAS_VARIADIC_TEMPLATES
-		#endif
-		#if GCC_VERSION >= 40400
-			#define HAS_INIT_LISTS
-		#endif
-	#endif
-	// FIXME: [romain] I did not actually check, tr1::unordered_map was 
-	// probably introduced before GCC 4.2.1
-	#if GCC_VERSION >= 40201
-		#define HAS_TR1
-		#define HAS_TR1_UNORDERED_MAP
-		#define HAS_TR1_UNORDERED_SET
-	#endif
+    #define GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)
+    #ifdef __GXX_EXPERIMENTAL_CXX0X__
+        #define HAS_CXX0X
+        #if GCC_VERSION >= 40300
+            #define HAS_VARIADIC_TEMPLATES
+        #endif
+        #if GCC_VERSION >= 40400
+            #define HAS_INIT_LISTS
+        #endif
+    #endif
+    // FIXME: [romain] I did not actually check, tr1::unordered_map was 
+    // probably introduced before GCC 4.2.1
+    #if GCC_VERSION >= 40201
+        #define HAS_TR1
+        #define HAS_TR1_UNORDERED_MAP
+        #define HAS_TR1_UNORDERED_SET
+    #endif
     // g++ 4.5 does not seem to like some of the fast indexing
     #if GCC_VERSION >= 40500
         #define IS_GCC_450_OR_LATER
@@ -118,7 +124,6 @@ namespace Rcpp{
 #include <numeric>
 #include <algorithm>
 #include <complex>
-#include <limits.h>
 #include <typeinfo>
 #include <Rcpp/sprintf.h>
 
@@ -146,7 +151,7 @@ std::string demangle( const std::string& name) ;
 #include <R_ext/Parse.h>
 #include <R_ext/Rdynload.h>
 #include <Rversion.h>
-#define RCPP_GET_NAMES(x)	Rf_getAttrib(x, R_NamesSymbol)
+#define RCPP_GET_NAMES(x)       Rf_getAttrib(x, R_NamesSymbol)
 
 inline SEXP Rcpp_lcons(SEXP car, SEXP cdr){
     PROTECT(car) ;
@@ -168,11 +173,11 @@ RcppExport void init_Rcpp_routines(DllInfo*) ;
 
 namespace Rcpp{
     namespace internal{
-		template <typename T> int rcpp_call_test(T t){
-			return T::r_type::value ;
-		}
-		int rcpp_call_test_(SEXP) ;
-	}
+        template <typename T> int rcpp_call_test(T t){
+            return T::r_type::value ;
+        }
+        int rcpp_call_test_(SEXP) ;
+    }
 }
 
 extern "C" SEXP rcpp_call_test(SEXP x) ;
@@ -202,22 +207,21 @@ const char * sexp_to_name(int sexp_type);
 #include <Rcpp/exceptions.h>
 
 namespace Rcpp{
-	/* internal namespace for things not intended to be used by the 
-	   user */
-	namespace internal{	
-	
-		/* defined in Evaluator.cpp */
-		SEXP convert_using_rfunction(SEXP x, const char* const fun) throw(::Rcpp::not_compatible) ;
-	
-		SEXP try_catch( SEXP expr, SEXP env ) throw(::Rcpp::eval_error) ;
-		SEXP try_catch( SEXP expr ) throw(::Rcpp::eval_error) ;
-	
-	} // namespace internal 
-
-	inline bool Rboolean_to_bool( int x){ return x == TRUE ; }
-	inline bool int_to_bool(int x){ return x != 0 ; }
-	inline bool double_to_bool(double x){ return x != 0.0 ; }
-	inline bool Rbyte_to_bool(Rbyte x){ return x != static_cast<Rbyte>(0) ; }
+    /* internal namespace for things not intended to be used by the user */
+    namespace internal{     
+        
+        /* defined in Evaluator.cpp */
+        SEXP convert_using_rfunction(SEXP x, const char* const fun);
+        
+        SEXP try_catch( SEXP expr, SEXP env );
+        SEXP try_catch( SEXP expr );
+        
+    } // namespace internal 
+    
+    inline bool Rboolean_to_bool( int x){ return x == TRUE ; }
+    inline bool int_to_bool(int x){ return x != 0 ; }
+    inline bool double_to_bool(double x){ return x != 0.0 ; }
+    inline bool Rbyte_to_bool(Rbyte x){ return x != static_cast<Rbyte>(0) ; }
 
 } // namespace Rcpp
 
@@ -225,23 +229,23 @@ namespace Rcpp{
 #define RCPP_DEBUG_LEVEL 0
 
 #ifndef logTxt
-	#if RCPP_DEBUG_LEVEL > 0
-		#define logTxt(x) ::logTxtFunction(__FILE__, __LINE__, x);
-	#else
-		#define logTxt(x)
-	#endif
+    #if RCPP_DEBUG_LEVEL > 0
+        #define logTxt(x) ::logTxtFunction(__FILE__, __LINE__, x);
+    #else
+        #define logTxt(x)
+    #endif
 #endif
 
 #if RCPP_DEBUG_LEVEL > 0
-	#define RCPP_DEBUG( MSG ) Rprintf( "%s:%d %s\n" , __FILE__, __LINE__, MSG ) ;
-	#define RCPP_DEBUG_1( fmt, MSG ) Rprintf( "%s:%d " fmt "\n" , __FILE__, __LINE__, MSG ) ;
-	#define RCPP_DEBUG_2( fmt, M1, M2 ) Rprintf( "%s:%d" fmt "\n" , __FILE__, __LINE__, M1, M2 ) ;
-	#define RCPP_DEBUG_3( fmt, M1, M2, M3 ) Rprintf( "%s:%d" fmt "\n" , __FILE__, __LINE__, M1, M2, M3) ;
+    #define RCPP_DEBUG( MSG ) Rprintf( "%s:%d %s\n" , __FILE__, __LINE__, MSG ) ;
+    #define RCPP_DEBUG_1( fmt, MSG ) Rprintf( "%s:%d " fmt "\n" , __FILE__, __LINE__, MSG ) ;
+    #define RCPP_DEBUG_2( fmt, M1, M2 ) Rprintf( "%s:%d" fmt "\n" , __FILE__, __LINE__, M1, M2 ) ;
+    #define RCPP_DEBUG_3( fmt, M1, M2, M3 ) Rprintf( "%s:%d" fmt "\n" , __FILE__, __LINE__, M1, M2, M3) ;
 #else
-	#define RCPP_DEBUG( MSG )
-	#define RCPP_DEBUG_1( fmt, MSG )
-	#define RCPP_DEBUG_2( fmt, M1, M2 )
-	#define RCPP_DEBUG_3( fmt, M1, M2, M3 )
+    #define RCPP_DEBUG( MSG )
+    #define RCPP_DEBUG_1( fmt, MSG )
+    #define RCPP_DEBUG_2( fmt, M1, M2 )
+    #define RCPP_DEBUG_3( fmt, M1, M2, M3 )
 #endif
 
 SEXP stack_trace( const char *file, int line) ;
@@ -249,18 +253,18 @@ SEXP stack_trace( const char *file, int line) ;
 #define Rcpp_error(MESSAGE) throw new Rcpp::exception( MESSAGE, __FILE__, __LINE__ ) 
 
 #if RCPP_DEBUG_LEVEL > 0
-  #include <typeinfo>
+    #include <typeinfo>
 #endif
 
-#ifdef __GNUC__
-#ifdef __GXX_EXPERIMENTAL_CXX0X__
-#ifdef LONG_LONG_MAX
-    __extension__ typedef long long int rcpp_long_long_type;
-    __extension__ typedef unsigned long long int rcpp_ulong_long_type;
-    #define RCPP_HAS_LONG_LONG_TYPES
-#endif
-#endif
-#endif
+// #ifdef __GNUC__
+// #ifdef __GXX_EXPERIMENTAL_CXX0X__
+// #ifdef LONG_LONG_MAX
+//     __extension__ typedef long long int rcpp_long_long_type;
+//     __extension__ typedef unsigned long long int rcpp_ulong_long_type;
+//     #define RCPP_HAS_LONG_LONG_TYPES
+// #endif
+// #endif
+// #endif
 
 // DO NOT CHANGE THE ORDER OF THESE INCLUDES
 #include <Rcpp/traits/integral_constant.h>
@@ -272,6 +276,7 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/expands_to_logical.h>
 #include <Rcpp/traits/matrix_interface.h>
 #include <Rcpp/traits/is_sugar_expression.h>
+#include <Rcpp/traits/is_eigen_base.h>
 #include <Rcpp/traits/has_na.h>
 #include <Rcpp/traits/storage_type.h>
 #include <Rcpp/traits/r_sexptype_traits.h>
@@ -283,6 +288,7 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/traits/get_na.h>
 #include <Rcpp/traits/is_trivial.h>
 #include <Rcpp/traits/init_type.h>
+#include <Rcpp/traits/or.h>
 
 #include <Rcpp/traits/is_const.h>
 #include <Rcpp/traits/is_reference.h>
@@ -297,6 +303,7 @@ SEXP stack_trace( const char *file, int line) ;
 #include <Rcpp/internal/r_vector.h>
 #include <Rcpp/r_cast.h>
 
+#include <Rcpp/int64/int64_lite.h>
 #include <Rcpp/internal/wrap_forward.h>
 
 #include <Rcpp/Date_forward.h>
